# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAlgGemeente(KeuzelijstField):
    """Lijst van gemeentes in Vlaanderen."""
    naam = 'KlAlgGemeente'
    label = 'Gemeente'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlAlgGemeente'
    definition = 'Lijst van gemeentes in Vlaanderen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAlgGemeente'
    options = {
        'aalst': KeuzelijstWaarde(invulwaarde='aalst',
                                  label='aalst',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/aalst'),
        'aalter': KeuzelijstWaarde(invulwaarde='aalter',
                                   label='aalter',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/aalter'),
        'aarschot': KeuzelijstWaarde(invulwaarde='aarschot',
                                     label='aarschot',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/aarschot'),
        'aartselaar': KeuzelijstWaarde(invulwaarde='aartselaar',
                                       label='aartselaar',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/aartselaar'),
        'affligem': KeuzelijstWaarde(invulwaarde='affligem',
                                     label='affligem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/affligem'),
        'alken': KeuzelijstWaarde(invulwaarde='alken',
                                  label='alken',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/alken'),
        'alveringem': KeuzelijstWaarde(invulwaarde='alveringem',
                                       label='alveringem',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/alveringem'),
        'antwerpen': KeuzelijstWaarde(invulwaarde='antwerpen',
                                      label='antwerpen',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/antwerpen'),
        'anzegem': KeuzelijstWaarde(invulwaarde='anzegem',
                                    label='anzegem',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/anzegem'),
        'ardooie': KeuzelijstWaarde(invulwaarde='ardooie',
                                    label='ardooie',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ardooie'),
        'arendonk': KeuzelijstWaarde(invulwaarde='arendonk',
                                     label='arendonk',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/arendonk'),
        'as': KeuzelijstWaarde(invulwaarde='as',
                               label='as',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/as'),
        'asse': KeuzelijstWaarde(invulwaarde='asse',
                                 label='asse',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/asse'),
        'assenede': KeuzelijstWaarde(invulwaarde='assenede',
                                     label='assenede',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/assenede'),
        'avelgem': KeuzelijstWaarde(invulwaarde='avelgem',
                                    label='avelgem',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/avelgem'),
        'baarle-Hertog': KeuzelijstWaarde(invulwaarde='baarle-Hertog',
                                          label='baarle-Hertog',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/baarle-Hertog'),
        'balen': KeuzelijstWaarde(invulwaarde='balen',
                                  label='balen',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/balen'),
        'beernem': KeuzelijstWaarde(invulwaarde='beernem',
                                    label='beernem',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/beernem'),
        'beerse': KeuzelijstWaarde(invulwaarde='beerse',
                                   label='beerse',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/beerse'),
        'beersel': KeuzelijstWaarde(invulwaarde='beersel',
                                    label='beersel',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/beersel'),
        'begijnendijk': KeuzelijstWaarde(invulwaarde='begijnendijk',
                                         label='begijnendijk',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/begijnendijk'),
        'bekkevoort': KeuzelijstWaarde(invulwaarde='bekkevoort',
                                       label='bekkevoort',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bekkevoort'),
        'beringen': KeuzelijstWaarde(invulwaarde='beringen',
                                     label='beringen',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/beringen'),
        'berlaar': KeuzelijstWaarde(invulwaarde='berlaar',
                                    label='berlaar',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/berlaar'),
        'berlare': KeuzelijstWaarde(invulwaarde='berlare',
                                    label='berlare',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/berlare'),
        'bertem': KeuzelijstWaarde(invulwaarde='bertem',
                                   label='bertem',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bertem'),
        'bever': KeuzelijstWaarde(invulwaarde='bever',
                                  label='bever',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bever'),
        'beveren': KeuzelijstWaarde(invulwaarde='beveren',
                                    label='beveren',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/beveren'),
        'bierbeek': KeuzelijstWaarde(invulwaarde='bierbeek',
                                     label='bierbeek',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bierbeek'),
        'bilzen': KeuzelijstWaarde(invulwaarde='bilzen',
                                   label='bilzen',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bilzen'),
        'blankenberge': KeuzelijstWaarde(invulwaarde='blankenberge',
                                         label='blankenberge',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/blankenberge'),
        'bocholt': KeuzelijstWaarde(invulwaarde='bocholt',
                                    label='bocholt',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bocholt'),
        'boechout': KeuzelijstWaarde(invulwaarde='boechout',
                                     label='boechout',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/boechout'),
        'bonheiden': KeuzelijstWaarde(invulwaarde='bonheiden',
                                      label='bonheiden',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bonheiden'),
        'boom': KeuzelijstWaarde(invulwaarde='boom',
                                 label='boom',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/boom'),
        'boortmeerbeek': KeuzelijstWaarde(invulwaarde='boortmeerbeek',
                                          label='boortmeerbeek',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/boortmeerbeek'),
        'borgloon': KeuzelijstWaarde(invulwaarde='borgloon',
                                     label='borgloon',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/borgloon'),
        'bornem': KeuzelijstWaarde(invulwaarde='bornem',
                                   label='bornem',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bornem'),
        'borsbeek': KeuzelijstWaarde(invulwaarde='borsbeek',
                                     label='borsbeek',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/borsbeek'),
        'boutersem': KeuzelijstWaarde(invulwaarde='boutersem',
                                      label='boutersem',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/boutersem'),
        'brakel': KeuzelijstWaarde(invulwaarde='brakel',
                                   label='brakel',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/brakel'),
        'brasschaat': KeuzelijstWaarde(invulwaarde='brasschaat',
                                       label='brasschaat',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/brasschaat'),
        'brecht': KeuzelijstWaarde(invulwaarde='brecht',
                                   label='brecht',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/brecht'),
        'bredene': KeuzelijstWaarde(invulwaarde='bredene',
                                    label='bredene',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bredene'),
        'bree': KeuzelijstWaarde(invulwaarde='bree',
                                 label='bree',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/bree'),
        'brugge': KeuzelijstWaarde(invulwaarde='brugge',
                                   label='brugge',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/brugge'),
        'buggenhout': KeuzelijstWaarde(invulwaarde='buggenhout',
                                       label='buggenhout',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/buggenhout'),
        'damme': KeuzelijstWaarde(invulwaarde='damme',
                                  label='damme',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/damme'),
        'de-Haan': KeuzelijstWaarde(invulwaarde='de-Haan',
                                    label='de Haan',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/de-Haan'),
        'de-Panne': KeuzelijstWaarde(invulwaarde='de-Panne',
                                     label='de Panne',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/de-Panne'),
        'de-Pinte': KeuzelijstWaarde(invulwaarde='de-Pinte',
                                     label='de Pinte',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/de-Pinte'),
        'deerlijk': KeuzelijstWaarde(invulwaarde='deerlijk',
                                     label='deerlijk',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/deerlijk'),
        'deinze': KeuzelijstWaarde(invulwaarde='deinze',
                                   label='deinze',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/deinze'),
        'denderleeuw': KeuzelijstWaarde(invulwaarde='denderleeuw',
                                        label='denderleeuw',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/denderleeuw'),
        'dendermonde': KeuzelijstWaarde(invulwaarde='dendermonde',
                                        label='dendermonde',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/dendermonde'),
        'dentergem': KeuzelijstWaarde(invulwaarde='dentergem',
                                      label='dentergem',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/dentergem'),
        'dessel': KeuzelijstWaarde(invulwaarde='dessel',
                                   label='dessel',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/dessel'),
        'destelbergen': KeuzelijstWaarde(invulwaarde='destelbergen',
                                         label='destelbergen',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/destelbergen'),
        'diepenbeek': KeuzelijstWaarde(invulwaarde='diepenbeek',
                                       label='diepenbeek',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/diepenbeek'),
        'diest': KeuzelijstWaarde(invulwaarde='diest',
                                  label='diest',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/diest'),
        'diksmuide': KeuzelijstWaarde(invulwaarde='diksmuide',
                                      label='diksmuide',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/diksmuide'),
        'dilbeek': KeuzelijstWaarde(invulwaarde='dilbeek',
                                    label='dilbeek',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/dilbeek'),
        'dilsen-Stokkem': KeuzelijstWaarde(invulwaarde='dilsen-Stokkem',
                                           label='dilsen-Stokkem',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/dilsen-Stokkem'),
        'drogenbos': KeuzelijstWaarde(invulwaarde='drogenbos',
                                      label='drogenbos',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/drogenbos'),
        'duffel': KeuzelijstWaarde(invulwaarde='duffel',
                                   label='duffel',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/duffel'),
        'edegem': KeuzelijstWaarde(invulwaarde='edegem',
                                   label='edegem',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/edegem'),
        'eeklo': KeuzelijstWaarde(invulwaarde='eeklo',
                                  label='eeklo',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/eeklo'),
        'erpe-Mere': KeuzelijstWaarde(invulwaarde='erpe-Mere',
                                      label='erpe-Mere',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/erpe-Mere'),
        'essen': KeuzelijstWaarde(invulwaarde='essen',
                                  label='essen',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/essen'),
        'evergem': KeuzelijstWaarde(invulwaarde='evergem',
                                    label='evergem',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/evergem'),
        'galmaarden': KeuzelijstWaarde(invulwaarde='galmaarden',
                                       label='galmaarden',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/galmaarden'),
        'gavere': KeuzelijstWaarde(invulwaarde='gavere',
                                   label='gavere',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/gavere'),
        'geel': KeuzelijstWaarde(invulwaarde='geel',
                                 label='geel',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/geel'),
        'geetbets': KeuzelijstWaarde(invulwaarde='geetbets',
                                     label='geetbets',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/geetbets'),
        'genk': KeuzelijstWaarde(invulwaarde='genk',
                                 label='genk',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/genk'),
        'gent': KeuzelijstWaarde(invulwaarde='gent',
                                 label='gent',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/gent'),
        'geraardsbergen': KeuzelijstWaarde(invulwaarde='geraardsbergen',
                                           label='geraardsbergen',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/geraardsbergen'),
        'gingelom': KeuzelijstWaarde(invulwaarde='gingelom',
                                     label='gingelom',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/gingelom'),
        'gistel': KeuzelijstWaarde(invulwaarde='gistel',
                                   label='gistel',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/gistel'),
        'glabbeek': KeuzelijstWaarde(invulwaarde='glabbeek',
                                     label='glabbeek',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/glabbeek'),
        'gooik': KeuzelijstWaarde(invulwaarde='gooik',
                                  label='gooik',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/gooik'),
        'grimbergen': KeuzelijstWaarde(invulwaarde='grimbergen',
                                       label='grimbergen',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/grimbergen'),
        'grobbendonk': KeuzelijstWaarde(invulwaarde='grobbendonk',
                                        label='grobbendonk',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/grobbendonk'),
        'haacht': KeuzelijstWaarde(invulwaarde='haacht',
                                   label='haacht',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/haacht'),
        'haaltert': KeuzelijstWaarde(invulwaarde='haaltert',
                                     label='haaltert',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/haaltert'),
        'halen': KeuzelijstWaarde(invulwaarde='halen',
                                  label='halen',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/halen'),
        'halle': KeuzelijstWaarde(invulwaarde='halle',
                                  label='halle',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/halle'),
        'ham': KeuzelijstWaarde(invulwaarde='ham',
                                label='ham',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ham'),
        'hamme': KeuzelijstWaarde(invulwaarde='hamme',
                                  label='hamme',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hamme'),
        'hamont-Achel': KeuzelijstWaarde(invulwaarde='hamont-Achel',
                                         label='hamont-Achel',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hamont-Achel'),
        'harelbeke': KeuzelijstWaarde(invulwaarde='harelbeke',
                                      label='harelbeke',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/harelbeke'),
        'hasselt': KeuzelijstWaarde(invulwaarde='hasselt',
                                    label='hasselt',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hasselt'),
        'hechtel-Eksel': KeuzelijstWaarde(invulwaarde='hechtel-Eksel',
                                          label='hechtel-Eksel',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hechtel-Eksel'),
        'heers': KeuzelijstWaarde(invulwaarde='heers',
                                  label='heers',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/heers'),
        'heist-op-den-Berg': KeuzelijstWaarde(invulwaarde='heist-op-den-Berg',
                                              label='heist-op-den-Berg',
                                              status='ingebruik',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/heist-op-den-Berg'),
        'hemiksem': KeuzelijstWaarde(invulwaarde='hemiksem',
                                     label='hemiksem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hemiksem'),
        'herent': KeuzelijstWaarde(invulwaarde='herent',
                                   label='herent',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/herent'),
        'herentals': KeuzelijstWaarde(invulwaarde='herentals',
                                      label='herentals',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/herentals'),
        'herenthout': KeuzelijstWaarde(invulwaarde='herenthout',
                                       label='herenthout',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/herenthout'),
        'herk-de-Stad': KeuzelijstWaarde(invulwaarde='herk-de-Stad',
                                         label='herk-de-Stad',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/herk-de-Stad'),
        'herne': KeuzelijstWaarde(invulwaarde='herne',
                                  label='herne',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/herne'),
        'herselt': KeuzelijstWaarde(invulwaarde='herselt',
                                    label='herselt',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/herselt'),
        'herstappe': KeuzelijstWaarde(invulwaarde='herstappe',
                                      label='herstappe',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/herstappe'),
        'herzele': KeuzelijstWaarde(invulwaarde='herzele',
                                    label='herzele',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/herzele'),
        'heusden-Zolder': KeuzelijstWaarde(invulwaarde='heusden-Zolder',
                                           label='heusden-Zolder',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/heusden-Zolder'),
        'heuvelland': KeuzelijstWaarde(invulwaarde='heuvelland',
                                       label='heuvelland',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/heuvelland'),
        'hoegaarden': KeuzelijstWaarde(invulwaarde='hoegaarden',
                                       label='hoegaarden',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hoegaarden'),
        'hoeilaart': KeuzelijstWaarde(invulwaarde='hoeilaart',
                                      label='hoeilaart',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hoeilaart'),
        'hoeselt': KeuzelijstWaarde(invulwaarde='hoeselt',
                                    label='hoeselt',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hoeselt'),
        'holsbeek': KeuzelijstWaarde(invulwaarde='holsbeek',
                                     label='holsbeek',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/holsbeek'),
        'hooglede': KeuzelijstWaarde(invulwaarde='hooglede',
                                     label='hooglede',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hooglede'),
        'hoogstraten': KeuzelijstWaarde(invulwaarde='hoogstraten',
                                        label='hoogstraten',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hoogstraten'),
        'horebeke': KeuzelijstWaarde(invulwaarde='horebeke',
                                     label='horebeke',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/horebeke'),
        'houthalen-Helchteren': KeuzelijstWaarde(invulwaarde='houthalen-Helchteren',
                                                 label='houthalen-Helchteren',
                                                 status='ingebruik',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/houthalen-Helchteren'),
        'houthulst': KeuzelijstWaarde(invulwaarde='houthulst',
                                      label='houthulst',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/houthulst'),
        'hove': KeuzelijstWaarde(invulwaarde='hove',
                                 label='hove',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hove'),
        'huldenberg': KeuzelijstWaarde(invulwaarde='huldenberg',
                                       label='huldenberg',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/huldenberg'),
        'hulshout': KeuzelijstWaarde(invulwaarde='hulshout',
                                     label='hulshout',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/hulshout'),
        'ichtegem': KeuzelijstWaarde(invulwaarde='ichtegem',
                                     label='ichtegem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ichtegem'),
        'ieper': KeuzelijstWaarde(invulwaarde='ieper',
                                  label='ieper',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ieper'),
        'ingelmunster': KeuzelijstWaarde(invulwaarde='ingelmunster',
                                         label='ingelmunster',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ingelmunster'),
        'izegem': KeuzelijstWaarde(invulwaarde='izegem',
                                   label='izegem',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/izegem'),
        'jabbeke': KeuzelijstWaarde(invulwaarde='jabbeke',
                                    label='jabbeke',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/jabbeke'),
        'kalmthout': KeuzelijstWaarde(invulwaarde='kalmthout',
                                      label='kalmthout',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kalmthout'),
        'kampenhout': KeuzelijstWaarde(invulwaarde='kampenhout',
                                       label='kampenhout',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kampenhout'),
        'kapelle-op-den-Bos': KeuzelijstWaarde(invulwaarde='kapelle-op-den-Bos',
                                               label='kapelle-op-den-Bos',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kapelle-op-den-Bos'),
        'kapellen': KeuzelijstWaarde(invulwaarde='kapellen',
                                     label='kapellen',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kapellen'),
        'kaprijke': KeuzelijstWaarde(invulwaarde='kaprijke',
                                     label='kaprijke',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kaprijke'),
        'kasterlee': KeuzelijstWaarde(invulwaarde='kasterlee',
                                      label='kasterlee',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kasterlee'),
        'keerbergen': KeuzelijstWaarde(invulwaarde='keerbergen',
                                       label='keerbergen',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/keerbergen'),
        'kinrooi': KeuzelijstWaarde(invulwaarde='kinrooi',
                                    label='kinrooi',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kinrooi'),
        'kluisbergen': KeuzelijstWaarde(invulwaarde='kluisbergen',
                                        label='kluisbergen',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kluisbergen'),
        'knesselare': KeuzelijstWaarde(invulwaarde='knesselare',
                                       label='knesselare',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/knesselare'),
        'knokke-Heist': KeuzelijstWaarde(invulwaarde='knokke-Heist',
                                         label='knokke-Heist',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/knokke-Heist'),
        'koekelare': KeuzelijstWaarde(invulwaarde='koekelare',
                                      label='koekelare',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/koekelare'),
        'koksijde': KeuzelijstWaarde(invulwaarde='koksijde',
                                     label='koksijde',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/koksijde'),
        'kontich': KeuzelijstWaarde(invulwaarde='kontich',
                                    label='kontich',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kontich'),
        'kortemark': KeuzelijstWaarde(invulwaarde='kortemark',
                                      label='kortemark',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kortemark'),
        'kortenaken': KeuzelijstWaarde(invulwaarde='kortenaken',
                                       label='kortenaken',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kortenaken'),
        'kortenberg': KeuzelijstWaarde(invulwaarde='kortenberg',
                                       label='kortenberg',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kortenberg'),
        'kortessem': KeuzelijstWaarde(invulwaarde='kortessem',
                                      label='kortessem',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kortessem'),
        'kortrijk': KeuzelijstWaarde(invulwaarde='kortrijk',
                                     label='kortrijk',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kortrijk'),
        'kraainem': KeuzelijstWaarde(invulwaarde='kraainem',
                                     label='kraainem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kraainem'),
        'kruibeke': KeuzelijstWaarde(invulwaarde='kruibeke',
                                     label='kruibeke',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kruibeke'),
        'kruisem': KeuzelijstWaarde(invulwaarde='kruisem',
                                    label='kruisem',
                                    status='ingebruik',
                                    definitie='Kruisem',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kruisem'),
        'kruishoutem': KeuzelijstWaarde(invulwaarde='kruishoutem',
                                        label='kruishoutem',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kruishoutem'),
        'kuurne': KeuzelijstWaarde(invulwaarde='kuurne',
                                   label='kuurne',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/kuurne'),
        'laakdal': KeuzelijstWaarde(invulwaarde='laakdal',
                                    label='laakdal',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/laakdal'),
        'laarne': KeuzelijstWaarde(invulwaarde='laarne',
                                   label='laarne',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/laarne'),
        'lanaken': KeuzelijstWaarde(invulwaarde='lanaken',
                                    label='lanaken',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lanaken'),
        'landen': KeuzelijstWaarde(invulwaarde='landen',
                                   label='landen',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/landen'),
        'langemark-Poelkapelle': KeuzelijstWaarde(invulwaarde='langemark-Poelkapelle',
                                                  label='langemark-Poelkapelle',
                                                  status='ingebruik',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/langemark-Poelkapelle'),
        'lebbeke': KeuzelijstWaarde(invulwaarde='lebbeke',
                                    label='lebbeke',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lebbeke'),
        'lede': KeuzelijstWaarde(invulwaarde='lede',
                                 label='lede',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lede'),
        'ledegem': KeuzelijstWaarde(invulwaarde='ledegem',
                                    label='ledegem',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ledegem'),
        'lendelede': KeuzelijstWaarde(invulwaarde='lendelede',
                                      label='lendelede',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lendelede'),
        'lennik': KeuzelijstWaarde(invulwaarde='lennik',
                                   label='lennik',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lennik'),
        'leopoldsburg': KeuzelijstWaarde(invulwaarde='leopoldsburg',
                                         label='leopoldsburg',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/leopoldsburg'),
        'leuven': KeuzelijstWaarde(invulwaarde='leuven',
                                   label='leuven',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/leuven'),
        'lichtervelde': KeuzelijstWaarde(invulwaarde='lichtervelde',
                                         label='lichtervelde',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lichtervelde'),
        'liedekerke': KeuzelijstWaarde(invulwaarde='liedekerke',
                                       label='liedekerke',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/liedekerke'),
        'lier': KeuzelijstWaarde(invulwaarde='lier',
                                 label='lier',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lier'),
        'lierde': KeuzelijstWaarde(invulwaarde='lierde',
                                   label='lierde',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lierde'),
        'lievegem': KeuzelijstWaarde(invulwaarde='lievegem',
                                     label='lievegem',
                                     status='ingebruik',
                                     definitie='Lievegem',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lievegem'),
        'lille': KeuzelijstWaarde(invulwaarde='lille',
                                  label='lille',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lille'),
        'linkebeek': KeuzelijstWaarde(invulwaarde='linkebeek',
                                      label='linkebeek',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/linkebeek'),
        'lint': KeuzelijstWaarde(invulwaarde='lint',
                                 label='lint',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lint'),
        'linter': KeuzelijstWaarde(invulwaarde='linter',
                                   label='linter',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/linter'),
        'lo-Reninge': KeuzelijstWaarde(invulwaarde='lo-Reninge',
                                       label='lo-Reninge',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lo-Reninge'),
        'lochristi': KeuzelijstWaarde(invulwaarde='lochristi',
                                      label='lochristi',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lochristi'),
        'lokeren': KeuzelijstWaarde(invulwaarde='lokeren',
                                    label='lokeren',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lokeren'),
        'lommel': KeuzelijstWaarde(invulwaarde='lommel',
                                   label='lommel',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lommel'),
        'londerzeel': KeuzelijstWaarde(invulwaarde='londerzeel',
                                       label='londerzeel',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/londerzeel'),
        'lovendegem': KeuzelijstWaarde(invulwaarde='lovendegem',
                                       label='lovendegem',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lovendegem'),
        'lubbeek': KeuzelijstWaarde(invulwaarde='lubbeek',
                                    label='lubbeek',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lubbeek'),
        'lummen': KeuzelijstWaarde(invulwaarde='lummen',
                                   label='lummen',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/lummen'),
        'maarkedal': KeuzelijstWaarde(invulwaarde='maarkedal',
                                      label='maarkedal',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/maarkedal'),
        'maaseik': KeuzelijstWaarde(invulwaarde='maaseik',
                                    label='maaseik',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/maaseik'),
        'maasmechelen': KeuzelijstWaarde(invulwaarde='maasmechelen',
                                         label='maasmechelen',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/maasmechelen'),
        'machelen': KeuzelijstWaarde(invulwaarde='machelen',
                                     label='machelen',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/machelen'),
        'maldegem': KeuzelijstWaarde(invulwaarde='maldegem',
                                     label='maldegem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/maldegem'),
        'malle': KeuzelijstWaarde(invulwaarde='malle',
                                  label='malle',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/malle'),
        'mechelen': KeuzelijstWaarde(invulwaarde='mechelen',
                                     label='mechelen',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/mechelen'),
        'meerhout': KeuzelijstWaarde(invulwaarde='meerhout',
                                     label='meerhout',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/meerhout'),
        'meeuwen-Gruitrode': KeuzelijstWaarde(invulwaarde='meeuwen-Gruitrode',
                                              label='meeuwen-Gruitrode',
                                              status='ingebruik',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/meeuwen-Gruitrode'),
        'meise': KeuzelijstWaarde(invulwaarde='meise',
                                  label='meise',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/meise'),
        'melle': KeuzelijstWaarde(invulwaarde='melle',
                                  label='melle',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/melle'),
        'menen': KeuzelijstWaarde(invulwaarde='menen',
                                  label='menen',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/menen'),
        'merchtem': KeuzelijstWaarde(invulwaarde='merchtem',
                                     label='merchtem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/merchtem'),
        'merelbeke': KeuzelijstWaarde(invulwaarde='merelbeke',
                                      label='merelbeke',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/merelbeke'),
        'merksplas': KeuzelijstWaarde(invulwaarde='merksplas',
                                      label='merksplas',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/merksplas'),
        'mesen': KeuzelijstWaarde(invulwaarde='mesen',
                                  label='mesen',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/mesen'),
        'meulebeke': KeuzelijstWaarde(invulwaarde='meulebeke',
                                      label='meulebeke',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/meulebeke'),
        'middelkerke': KeuzelijstWaarde(invulwaarde='middelkerke',
                                        label='middelkerke',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/middelkerke'),
        'moerbeke': KeuzelijstWaarde(invulwaarde='moerbeke',
                                     label='moerbeke',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/moerbeke'),
        'mol': KeuzelijstWaarde(invulwaarde='mol',
                                label='mol',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/mol'),
        'moorslede': KeuzelijstWaarde(invulwaarde='moorslede',
                                      label='moorslede',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/moorslede'),
        'mortsel': KeuzelijstWaarde(invulwaarde='mortsel',
                                    label='mortsel',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/mortsel'),
        'nazareth': KeuzelijstWaarde(invulwaarde='nazareth',
                                     label='nazareth',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/nazareth'),
        'neerpelt': KeuzelijstWaarde(invulwaarde='neerpelt',
                                     label='neerpelt',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/neerpelt'),
        'nevele': KeuzelijstWaarde(invulwaarde='nevele',
                                   label='nevele',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/nevele'),
        'niel': KeuzelijstWaarde(invulwaarde='niel',
                                 label='niel',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/niel'),
        'nieuwerkerken': KeuzelijstWaarde(invulwaarde='nieuwerkerken',
                                          label='nieuwerkerken',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/nieuwerkerken'),
        'nieuwpoort': KeuzelijstWaarde(invulwaarde='nieuwpoort',
                                       label='nieuwpoort',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/nieuwpoort'),
        'nijlen': KeuzelijstWaarde(invulwaarde='nijlen',
                                   label='nijlen',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/nijlen'),
        'ninove': KeuzelijstWaarde(invulwaarde='ninove',
                                   label='ninove',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ninove'),
        'olen': KeuzelijstWaarde(invulwaarde='olen',
                                 label='olen',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/olen'),
        'oostende': KeuzelijstWaarde(invulwaarde='oostende',
                                     label='oostende',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/oostende'),
        'oosterzele': KeuzelijstWaarde(invulwaarde='oosterzele',
                                       label='oosterzele',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/oosterzele'),
        'oostkamp': KeuzelijstWaarde(invulwaarde='oostkamp',
                                     label='oostkamp',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/oostkamp'),
        'oostrozebeke': KeuzelijstWaarde(invulwaarde='oostrozebeke',
                                         label='oostrozebeke',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/oostrozebeke'),
        'opglabbeek': KeuzelijstWaarde(invulwaarde='opglabbeek',
                                       label='opglabbeek',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/opglabbeek'),
        'opwijk': KeuzelijstWaarde(invulwaarde='opwijk',
                                   label='opwijk',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/opwijk'),
        'oud-Heverlee': KeuzelijstWaarde(invulwaarde='oud-Heverlee',
                                         label='oud-Heverlee',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/oud-Heverlee'),
        'oud-Turnhout': KeuzelijstWaarde(invulwaarde='oud-Turnhout',
                                         label='oud-Turnhout',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/oud-Turnhout'),
        'oudenaarde': KeuzelijstWaarde(invulwaarde='oudenaarde',
                                       label='oudenaarde',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/oudenaarde'),
        'oudenburg': KeuzelijstWaarde(invulwaarde='oudenburg',
                                      label='oudenburg',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/oudenburg'),
        'oudsbergen': KeuzelijstWaarde(invulwaarde='oudsbergen',
                                       label='oudsbergen',
                                       status='ingebruik',
                                       definitie='Oudsbergen',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/oudsbergen'),
        'overijse': KeuzelijstWaarde(invulwaarde='overijse',
                                     label='overijse',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/overijse'),
        'overpelt': KeuzelijstWaarde(invulwaarde='overpelt',
                                     label='overpelt',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/overpelt'),
        'peer': KeuzelijstWaarde(invulwaarde='peer',
                                 label='peer',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/peer'),
        'pelt': KeuzelijstWaarde(invulwaarde='pelt',
                                 label='pelt',
                                 status='ingebruik',
                                 definitie='Pelt',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/pelt'),
        'pepingen': KeuzelijstWaarde(invulwaarde='pepingen',
                                     label='pepingen',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/pepingen'),
        'pittem': KeuzelijstWaarde(invulwaarde='pittem',
                                   label='pittem',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/pittem'),
        'poperinge': KeuzelijstWaarde(invulwaarde='poperinge',
                                      label='poperinge',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/poperinge'),
        'putte': KeuzelijstWaarde(invulwaarde='putte',
                                  label='putte',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/putte'),
        'puurs': KeuzelijstWaarde(invulwaarde='puurs',
                                  label='puurs',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/puurs'),
        'puurs-sint-amands': KeuzelijstWaarde(invulwaarde='puurs-sint-amands',
                                              label='puurs-Sint-Amands',
                                              status='ingebruik',
                                              definitie='Puurs-Sint-Amands',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/puurs-sint-amands'),
        'ranst': KeuzelijstWaarde(invulwaarde='ranst',
                                  label='ranst',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ranst'),
        'ravels': KeuzelijstWaarde(invulwaarde='ravels',
                                   label='ravels',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ravels'),
        'retie': KeuzelijstWaarde(invulwaarde='retie',
                                  label='retie',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/retie'),
        'riemst': KeuzelijstWaarde(invulwaarde='riemst',
                                   label='riemst',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/riemst'),
        'rijkevorsel': KeuzelijstWaarde(invulwaarde='rijkevorsel',
                                        label='rijkevorsel',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/rijkevorsel'),
        'roeselare': KeuzelijstWaarde(invulwaarde='roeselare',
                                      label='roeselare',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/roeselare'),
        'ronse': KeuzelijstWaarde(invulwaarde='ronse',
                                  label='ronse',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ronse'),
        'roosdaal': KeuzelijstWaarde(invulwaarde='roosdaal',
                                     label='roosdaal',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/roosdaal'),
        'rotselaar': KeuzelijstWaarde(invulwaarde='rotselaar',
                                      label='rotselaar',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/rotselaar'),
        'ruiselede': KeuzelijstWaarde(invulwaarde='ruiselede',
                                      label='ruiselede',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ruiselede'),
        'rumst': KeuzelijstWaarde(invulwaarde='rumst',
                                  label='rumst',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/rumst'),
        'schelle': KeuzelijstWaarde(invulwaarde='schelle',
                                    label='schelle',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/schelle'),
        'scherpenheuvel-Zichem': KeuzelijstWaarde(invulwaarde='scherpenheuvel-Zichem',
                                                  label='scherpenheuvel-Zichem',
                                                  status='ingebruik',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/scherpenheuvel-Zichem'),
        'schilde': KeuzelijstWaarde(invulwaarde='schilde',
                                    label='schilde',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/schilde'),
        'schoten': KeuzelijstWaarde(invulwaarde='schoten',
                                    label='schoten',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/schoten'),
        'sint-Amands': KeuzelijstWaarde(invulwaarde='sint-Amands',
                                        label='sint-Amands',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Amands'),
        'sint-Genesius-Rode': KeuzelijstWaarde(invulwaarde='sint-Genesius-Rode',
                                               label='sint-Genesius-Rode',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Genesius-Rode'),
        'sint-Gillis-Waas': KeuzelijstWaarde(invulwaarde='sint-Gillis-Waas',
                                             label='sint-Gillis-Waas',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Gillis-Waas'),
        'sint-Katelijne-Waver': KeuzelijstWaarde(invulwaarde='sint-Katelijne-Waver',
                                                 label='sint-Katelijne-Waver',
                                                 status='ingebruik',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Katelijne-Waver'),
        'sint-Laureins': KeuzelijstWaarde(invulwaarde='sint-Laureins',
                                          label='sint-Laureins',
                                          status='ingebruik',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Laureins'),
        'sint-Lievens-Houtem': KeuzelijstWaarde(invulwaarde='sint-Lievens-Houtem',
                                                label='sint-Lievens-Houtem',
                                                status='ingebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Lievens-Houtem'),
        'sint-Martens-Latem': KeuzelijstWaarde(invulwaarde='sint-Martens-Latem',
                                               label='sint-Martens-Latem',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Martens-Latem'),
        'sint-Niklaas': KeuzelijstWaarde(invulwaarde='sint-Niklaas',
                                         label='sint-Niklaas',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Niklaas'),
        'sint-Pieters-Leeuw': KeuzelijstWaarde(invulwaarde='sint-Pieters-Leeuw',
                                               label='sint-Pieters-Leeuw',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Pieters-Leeuw'),
        'sint-Truiden': KeuzelijstWaarde(invulwaarde='sint-Truiden',
                                         label='sint-Truiden',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/sint-Truiden'),
        'spiere-Helkijn': KeuzelijstWaarde(invulwaarde='spiere-Helkijn',
                                           label='spiere-Helkijn',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/spiere-Helkijn'),
        'stabroek': KeuzelijstWaarde(invulwaarde='stabroek',
                                     label='stabroek',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/stabroek'),
        'staden': KeuzelijstWaarde(invulwaarde='staden',
                                   label='staden',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/staden'),
        'steenokkerzeel': KeuzelijstWaarde(invulwaarde='steenokkerzeel',
                                           label='steenokkerzeel',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/steenokkerzeel'),
        'stekene': KeuzelijstWaarde(invulwaarde='stekene',
                                    label='stekene',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/stekene'),
        'temse': KeuzelijstWaarde(invulwaarde='temse',
                                  label='temse',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/temse'),
        'ternat': KeuzelijstWaarde(invulwaarde='ternat',
                                   label='ternat',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/ternat'),
        'tervuren': KeuzelijstWaarde(invulwaarde='tervuren',
                                     label='tervuren',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/tervuren'),
        'tessenderlo': KeuzelijstWaarde(invulwaarde='tessenderlo',
                                        label='tessenderlo',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/tessenderlo'),
        'tielt': KeuzelijstWaarde(invulwaarde='tielt',
                                  label='tielt',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/tielt'),
        'tielt-Winge': KeuzelijstWaarde(invulwaarde='tielt-Winge',
                                        label='tielt-Winge',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/tielt-Winge'),
        'tienen': KeuzelijstWaarde(invulwaarde='tienen',
                                   label='tienen',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/tienen'),
        'tongeren': KeuzelijstWaarde(invulwaarde='tongeren',
                                     label='tongeren',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/tongeren'),
        'torhout': KeuzelijstWaarde(invulwaarde='torhout',
                                    label='torhout',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/torhout'),
        'tremelo': KeuzelijstWaarde(invulwaarde='tremelo',
                                    label='tremelo',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/tremelo'),
        'turnhout': KeuzelijstWaarde(invulwaarde='turnhout',
                                     label='turnhout',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/turnhout'),
        'veurne': KeuzelijstWaarde(invulwaarde='veurne',
                                   label='veurne',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/veurne'),
        'vilvoorde': KeuzelijstWaarde(invulwaarde='vilvoorde',
                                      label='vilvoorde',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/vilvoorde'),
        'vleteren': KeuzelijstWaarde(invulwaarde='vleteren',
                                     label='vleteren',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/vleteren'),
        'voeren': KeuzelijstWaarde(invulwaarde='voeren',
                                   label='voeren',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/voeren'),
        'vorselaar': KeuzelijstWaarde(invulwaarde='vorselaar',
                                      label='vorselaar',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/vorselaar'),
        'vosselaar': KeuzelijstWaarde(invulwaarde='vosselaar',
                                      label='vosselaar',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/vosselaar'),
        'waarschoot': KeuzelijstWaarde(invulwaarde='waarschoot',
                                       label='waarschoot',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/waarschoot'),
        'waasmunster': KeuzelijstWaarde(invulwaarde='waasmunster',
                                        label='waasmunster',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/waasmunster'),
        'wachtebeke': KeuzelijstWaarde(invulwaarde='wachtebeke',
                                       label='wachtebeke',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wachtebeke'),
        'waregem': KeuzelijstWaarde(invulwaarde='waregem',
                                    label='waregem',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/waregem'),
        'wellen': KeuzelijstWaarde(invulwaarde='wellen',
                                   label='wellen',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wellen'),
        'wemmel': KeuzelijstWaarde(invulwaarde='wemmel',
                                   label='wemmel',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wemmel'),
        'wervik': KeuzelijstWaarde(invulwaarde='wervik',
                                   label='wervik',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wervik'),
        'westerlo': KeuzelijstWaarde(invulwaarde='westerlo',
                                     label='westerlo',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/westerlo'),
        'wetteren': KeuzelijstWaarde(invulwaarde='wetteren',
                                     label='wetteren',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wetteren'),
        'wevelgem': KeuzelijstWaarde(invulwaarde='wevelgem',
                                     label='wevelgem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wevelgem'),
        'wezembeek-Oppem': KeuzelijstWaarde(invulwaarde='wezembeek-Oppem',
                                            label='wezembeek-Oppem',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wezembeek-Oppem'),
        'wichelen': KeuzelijstWaarde(invulwaarde='wichelen',
                                     label='wichelen',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wichelen'),
        'wielsbeke': KeuzelijstWaarde(invulwaarde='wielsbeke',
                                      label='wielsbeke',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wielsbeke'),
        'wijnegem': KeuzelijstWaarde(invulwaarde='wijnegem',
                                     label='wijnegem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wijnegem'),
        'willebroek': KeuzelijstWaarde(invulwaarde='willebroek',
                                       label='willebroek',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/willebroek'),
        'wingene': KeuzelijstWaarde(invulwaarde='wingene',
                                    label='wingene',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wingene'),
        'wommelgem': KeuzelijstWaarde(invulwaarde='wommelgem',
                                      label='wommelgem',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wommelgem'),
        'wortegem-Petegem': KeuzelijstWaarde(invulwaarde='wortegem-Petegem',
                                             label='wortegem-Petegem',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wortegem-Petegem'),
        'wuustwezel': KeuzelijstWaarde(invulwaarde='wuustwezel',
                                       label='wuustwezel',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/wuustwezel'),
        'zandhoven': KeuzelijstWaarde(invulwaarde='zandhoven',
                                      label='zandhoven',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zandhoven'),
        'zaventem': KeuzelijstWaarde(invulwaarde='zaventem',
                                     label='zaventem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zaventem'),
        'zedelgem': KeuzelijstWaarde(invulwaarde='zedelgem',
                                     label='zedelgem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zedelgem'),
        'zele': KeuzelijstWaarde(invulwaarde='zele',
                                 label='zele',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zele'),
        'zelzate': KeuzelijstWaarde(invulwaarde='zelzate',
                                    label='zelzate',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zelzate'),
        'zemst': KeuzelijstWaarde(invulwaarde='zemst',
                                  label='zemst',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zemst'),
        'zingem': KeuzelijstWaarde(invulwaarde='zingem',
                                   label='zingem',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zingem'),
        'zoersel': KeuzelijstWaarde(invulwaarde='zoersel',
                                    label='zoersel',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zoersel'),
        'zomergem': KeuzelijstWaarde(invulwaarde='zomergem',
                                     label='zomergem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zomergem'),
        'zonhoven': KeuzelijstWaarde(invulwaarde='zonhoven',
                                     label='zonhoven',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zonhoven'),
        'zonnebeke': KeuzelijstWaarde(invulwaarde='zonnebeke',
                                      label='zonnebeke',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zonnebeke'),
        'zottegem': KeuzelijstWaarde(invulwaarde='zottegem',
                                     label='zottegem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zottegem'),
        'zoutleeuw': KeuzelijstWaarde(invulwaarde='zoutleeuw',
                                      label='zoutleeuw',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zoutleeuw'),
        'zuienkerke': KeuzelijstWaarde(invulwaarde='zuienkerke',
                                       label='zuienkerke',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zuienkerke'),
        'zulte': KeuzelijstWaarde(invulwaarde='zulte',
                                  label='zulte',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zulte'),
        'zutendaal': KeuzelijstWaarde(invulwaarde='zutendaal',
                                      label='zutendaal',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zutendaal'),
        'zwalm': KeuzelijstWaarde(invulwaarde='zwalm',
                                  label='zwalm',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zwalm'),
        'zwevegem': KeuzelijstWaarde(invulwaarde='zwevegem',
                                     label='zwevegem',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zwevegem'),
        'zwijndrecht': KeuzelijstWaarde(invulwaarde='zwijndrecht',
                                        label='zwijndrecht',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAlgGemeente/zwijndrecht')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

