# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBuisbekledingUitvoeringswijze(KeuzelijstField):
    """Materiaal en manier van aanbrengen van de buisbekleding."""
    naam = 'KlBuisbekledingUitvoeringswijze'
    label = 'uitvoeringswijze buisbekleding'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBuisbekledingUitvoeringswijze'
    definition = 'Materiaal en manier van aanbrengen van de buisbekleding.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBuisbekledingUitvoeringswijze'
    options = {
        'bouwput-voor-rioolrenovatie-dmv-buis-in-buissysteem-met-glasvezelversterkte-polyesterelementen': KeuzelijstWaarde(invulwaarde='bouwput-voor-rioolrenovatie-dmv-buis-in-buissysteem-met-glasvezelversterkte-polyesterelementen',
                                                                                                                           label='bouwput voor rioolrenovatie dmv buis in buissysteem met glasvezelversterkte polyesterelementen',
                                                                                                                           status='ingebruik',
                                                                                                                           definitie='Bouwput voor rioolrenovatie dmv buis in buissysteem met glasvezelversterkte polyesterelementen',
                                                                                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/bouwput-voor-rioolrenovatie-dmv-buis-in-buissysteem-met-glasvezelversterkte-polyesterelementen'),
        'buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-140': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-140',
                                                                                              label='buis in buis renovatie met hard-PVC-wikkelbuizen. profiel nr. 140',
                                                                                              status='ingebruik',
                                                                                              definitie='Buis in buis renovatie met hard-PVC-wikkelbuizen, profiel nr. 140',
                                                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-140'),
        'buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-50': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-50',
                                                                                             label='buis in buis renovatie met hard-PVC-wikkelbuizen. profiel nr. 50',
                                                                                             status='ingebruik',
                                                                                             definitie='Buis in buis renovatie met hard-PVC-wikkelbuizen, profiel nr. 50',
                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-50'),
        'buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-60': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-60',
                                                                                             label='buis in buis renovatie met hard-PVC-wikkelbuizen. profiel nr. 60',
                                                                                             status='ingebruik',
                                                                                             definitie='Buis in buis renovatie met hard-PVC-wikkelbuizen, profiel nr. 60',
                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-60'),
        'buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-90': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-90',
                                                                                             label='buis in buis renovatie met hard-PVC-wikkelbuizen. profiel nr. 90',
                                                                                             status='ingebruik',
                                                                                             definitie='Buis in buis renovatie met hard-PVC-wikkelbuizen, profiel nr. 90',
                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-90'),
        'buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-10000-N-mm2': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-10000-N-mm2',
                                                                                                           label='buis in buis renovatie met standaardbuizen in GVP. sterktereeks SN 10000 N-mm2',
                                                                                                           status='ingebruik',
                                                                                                           definitie='Buis in buis renovatie met standaardbuizen in GVP, sterktereeks SN 10000 N/mm2',
                                                                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-10000-N-mm2'),
        'buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-2500-N-mm2': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-2500-N-mm2',
                                                                                                          label='buis in buis renovatie met standaardbuizen in GVP. sterktereeks SN 2500 N-mm2',
                                                                                                          status='ingebruik',
                                                                                                          definitie='Buis in buis renovatie met standaardbuizen in GVP, sterktereeks SN 2500 N/mm2',
                                                                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-2500-N-mm2'),
        'buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-5000-N-mm2': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-5000-N-mm2',
                                                                                                          label='buis in buis renovatie met standaardbuizen in GVP. sterktereeks SN 5000 N-mm2',
                                                                                                          status='ingebruik',
                                                                                                          definitie='Buis in buis renovatie met standaardbuizen in GVP, sterktereeks SN 5000 N/mm2',
                                                                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-5000-N-mm2'),
        'buis-in-buis-renovatie.-met-wandversterkte-HDPE-buizen': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie.-met-wandversterkte-HDPE-buizen',
                                                                                   label='buis in buis renovatie. met wandversterkte HDPE-buizen',
                                                                                   status='ingebruik',
                                                                                   definitie='Buis in buis renovatie, met wandversterkte HDPE-buizen',
                                                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie.-met-wandversterkte-HDPE-buizen'),
        'gunitage-via-de-natte-spuitmethode.-met-wapening.-glad-oppervlak': KeuzelijstWaarde(invulwaarde='gunitage-via-de-natte-spuitmethode.-met-wapening.-glad-oppervlak',
                                                                                             label='gunitage via de natte spuitmethode. met wapening. glad oppervlak',
                                                                                             status='ingebruik',
                                                                                             definitie='Gunitage via de natte spuitmethode, met wapening, glad oppervlak',
                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/gunitage-via-de-natte-spuitmethode.-met-wapening.-glad-oppervlak'),
        'gunitage-via-de-natte-spuitmethode.-met-wapening.-ruw-oppervlak': KeuzelijstWaarde(invulwaarde='gunitage-via-de-natte-spuitmethode.-met-wapening.-ruw-oppervlak',
                                                                                            label='gunitage via de natte spuitmethode. met wapening. ruw oppervlak',
                                                                                            status='ingebruik',
                                                                                            definitie='Gunitage via de natte spuitmethode, met wapening, ruw oppervlak',
                                                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/gunitage-via-de-natte-spuitmethode.-met-wapening.-ruw-oppervlak'),
        'gunitage-via-de-natte-spuitmethode.-zonder-wapening.-glad-oppervlak': KeuzelijstWaarde(invulwaarde='gunitage-via-de-natte-spuitmethode.-zonder-wapening.-glad-oppervlak',
                                                                                                label='gunitage via de natte spuitmethode. zonder wapening. glad oppervlak',
                                                                                                status='ingebruik',
                                                                                                definitie='Gunitage via de natte spuitmethode, zonder wapening, glad oppervlak',
                                                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/gunitage-via-de-natte-spuitmethode.-zonder-wapening.-glad-oppervlak'),
        'gunitage-via-de-natte-spuitmethode.-zonder-wapening.-ruw-oppervlak': KeuzelijstWaarde(invulwaarde='gunitage-via-de-natte-spuitmethode.-zonder-wapening.-ruw-oppervlak',
                                                                                               label='gunitage via de natte spuitmethode. zonder wapening. ruw oppervlak',
                                                                                               status='ingebruik',
                                                                                               definitie='Gunitage via de natte spuitmethode, zonder wapening, ruw oppervlak',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/gunitage-via-de-natte-spuitmethode.-zonder-wapening.-ruw-oppervlak'),
        'herstelling-van-lekkende-voegverbindingen-en-grindnesten-door-middel-van-het-plaatsen-van-inox-manchetten-in-buisleidingen': KeuzelijstWaarde(invulwaarde='herstelling-van-lekkende-voegverbindingen-en-grindnesten-door-middel-van-het-plaatsen-van-inox-manchetten-in-buisleidingen',
                                                                                                                                                       label='herstelling van lekkende voegverbindingen en grindnesten door middel van het plaatsen van inox manchetten in buisleidingen',
                                                                                                                                                       status='ingebruik',
                                                                                                                                                       definitie='Herstelling van lekkende voegverbindingen en grindnesten door middel van het plaatsen van inox manchetten in buisleidingen',
                                                                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/herstelling-van-lekkende-voegverbindingen-en-grindnesten-door-middel-van-het-plaatsen-van-inox-manchetten-in-buisleidingen'),
        'inwendige-bekleding-met-PUR-verf-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='inwendige-bekleding-met-PUR-verf-voor-buizen-van-nodulair-gietijzer',
                                                                                                label='inwendige bekleding met PUR-verf voor buizen van nodulair gietijzer',
                                                                                                status='ingebruik',
                                                                                                definitie='inwendige bekleding met PUR-verf voor buizen van nodC3:C48ulair gietijzer',
                                                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/inwendige-bekleding-met-PUR-verf-voor-buizen-van-nodulair-gietijzer'),
        'pipebursting': KeuzelijstWaarde(invulwaarde='pipebursting',
                                         label='pipebursting',
                                         status='ingebruik',
                                         definitie='pipebursting',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/pipebursting'),
        'renovatie-door-lining-met-TUB-met-structureel-onvoldoende-reststerkte': KeuzelijstWaarde(invulwaarde='renovatie-door-lining-met-TUB-met-structureel-onvoldoende-reststerkte',
                                                                                                  label='renovatie door lining met TUB met structureel onvoldoende reststerkte',
                                                                                                  status='ingebruik',
                                                                                                  definitie='Renovatie door lining met TUB met structureel onvoldoende reststerkte',
                                                                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-door-lining-met-TUB-met-structureel-onvoldoende-reststerkte'),
        'renovatie-door-lining-met-TUB-met-structureel-voldoende-reststerkte': KeuzelijstWaarde(invulwaarde='renovatie-door-lining-met-TUB-met-structureel-voldoende-reststerkte',
                                                                                                label='renovatie door lining met TUB met structureel voldoende reststerkte',
                                                                                                status='ingebruik',
                                                                                                definitie='Renovatie door lining met TUB met structureel voldoende reststerkte',
                                                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-door-lining-met-TUB-met-structureel-voldoende-reststerkte'),
        'renovatie-door-middel-van-solventvrije-vezelversterkte-kunstharsen': KeuzelijstWaarde(invulwaarde='renovatie-door-middel-van-solventvrije-vezelversterkte-kunstharsen',
                                                                                               label='renovatie door middel van solventvrije vezelversterkte kunstharsen',
                                                                                               status='ingebruik',
                                                                                               definitie='Renovatie door middel van solventvrije vezelversterkte kunstharsen',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-door-middel-van-solventvrije-vezelversterkte-kunstharsen'),
        'renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-elementen': KeuzelijstWaarde(invulwaarde='renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-elementen',
                                                                                              label='renovatie stroomprofiel met buis in buissysteem met GVP-elementen',
                                                                                              status='ingebruik',
                                                                                              definitie='Renovatie stroomprofiel met buis in buissysteem met GVP-elementen',
                                                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-elementen'),
        'renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-panelen': KeuzelijstWaarde(invulwaarde='renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-panelen',
                                                                                            label='renovatie stroomprofiel met buis in buissysteem met GVP-panelen',
                                                                                            status='ingebruik',
                                                                                            definitie='Renovatie stroomprofiel met buis in buissysteem met GVP-panelen',
                                                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-panelen'),
        'renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-elementen': KeuzelijstWaarde(invulwaarde='renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-elementen',
                                                                                                        label='renovatie volledige leidingsectie met buis in buissysteem met GVP-elementen',
                                                                                                        status='ingebruik',
                                                                                                        definitie='Renovatie volledige leidingsectie met buis in buissysteem met GVP-elementen',
                                                                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-elementen'),
        'renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-panelen': KeuzelijstWaarde(invulwaarde='renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-panelen',
                                                                                                      label='renovatie volledige leidingsectie met buis in buissysteem met GVP-panelen',
                                                                                                      status='ingebruik',
                                                                                                      definitie='Renovatie volledige leidingsectie met buis in buissysteem met GVP-panelen',
                                                                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-panelen'),
        'rioolrenovatie-d.m.v.-deelrenovatie-met-glasvezelversterkt-kunsthars': KeuzelijstWaarde(invulwaarde='rioolrenovatie-d.m.v.-deelrenovatie-met-glasvezelversterkt-kunsthars',
                                                                                                 label='rioolrenovatie d.m.v. deelrenovatie met glasvezelversterkt kunsthars',
                                                                                                 status='ingebruik',
                                                                                                 definitie='Rioolrenovatie d.m.v. deelrenovatie met glasvezelversterkt kunsthars',
                                                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/rioolrenovatie-d.m.v.-deelrenovatie-met-glasvezelversterkt-kunsthars'),
        'rioolrenovatie-dmv-close-fit-lining-met-fabrieksmatig-gevouwen-HDPE-buizen-met-diameter': KeuzelijstWaarde(invulwaarde='rioolrenovatie-dmv-close-fit-lining-met-fabrieksmatig-gevouwen-HDPE-buizen-met-diameter',
                                                                                                                    label='rioolrenovatie dmv close-fit lining met fabrieksmatig gevouwen HDPE-buizen met diameter',
                                                                                                                    status='ingebruik',
                                                                                                                    definitie='Rioolrenovatie dmv close-fit lining met fabrieksmatig gevouwen HDPE-buizen met diameter',
                                                                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/rioolrenovatie-dmv-close-fit-lining-met-fabrieksmatig-gevouwen-HDPE-buizen-met-diameter'),
        'rioolrenovatie-door-middel-van-HDPE-grout-liner': KeuzelijstWaarde(invulwaarde='rioolrenovatie-door-middel-van-HDPE-grout-liner',
                                                                            label='rioolrenovatie door middel van HDPE-grout liner',
                                                                            status='ingebruik',
                                                                            definitie='Rioolrenovatie door middel van HDPE/grout liner',
                                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/rioolrenovatie-door-middel-van-HDPE-grout-liner'),
        'uitwendige-aangepaste-PUR-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='uitwendige-aangepaste-PUR-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer',
                                                                                                                             label='uitwendige aangepaste PUR-bekleding aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                             status='ingebruik',
                                                                                                                             definitie='uitwendige aangepaste PUR-bekleding aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/uitwendige-aangepaste-PUR-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer'),
        'uitwendige-beschermbanden-met-PE-inlage-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='uitwendige-beschermbanden-met-PE-inlage-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer',
                                                                                                                                 label='uitwendige beschermbanden met PE-inlage aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                                 status='ingebruik',
                                                                                                                                 definitie='uitwendige beschermbanden met PE-inlage aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/uitwendige-beschermbanden-met-PE-inlage-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer'),
        'uitwendige-geextrudeerde-PE-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='uitwendige-geextrudeerde-PE-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer',
                                                                                                                               label='uitwendige geextrudeerde PE-bekleding aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                               status='ingebruik',
                                                                                                                               definitie='uitwendige geextrudeerde PE-bekleding aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/uitwendige-geextrudeerde-PE-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer'),
        'uitwendige-waterdichte-PE-folie-op-de-werf-aangebracht-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='uitwendige-waterdichte-PE-folie-op-de-werf-aangebracht-voor-buizen-van-nodulair-gietijzer',
                                                                                                                      label='uitwendige waterdichte PE-folie op de werf aangebracht voor buizen van nodulair gietijzer',
                                                                                                                      status='ingebruik',
                                                                                                                      definitie='uitwendige waterdichte PE-folie op de werf aangebracht voor buizen van nodulair gietijzer',
                                                                                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/uitwendige-waterdichte-PE-folie-op-de-werf-aangebracht-voor-buizen-van-nodulair-gietijzer'),
        'waterdichting-door-middel-van-injectieharsen': KeuzelijstWaarde(invulwaarde='waterdichting-door-middel-van-injectieharsen',
                                                                         label='waterdichting door middel van injectieharsen',
                                                                         status='ingebruik',
                                                                         definitie='Waterdichting door middel van injectieharsen',
                                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/waterdichting-door-middel-van-injectieharsen'),
        'waterdichting-door-middel-van-injectieharsen-in-man-toegankelijke-riolen': KeuzelijstWaarde(invulwaarde='waterdichting-door-middel-van-injectieharsen-in-man-toegankelijke-riolen',
                                                                                                     label='waterdichting door middel van injectieharsen in man-toegankelijke riolen',
                                                                                                     status='ingebruik',
                                                                                                     definitie='Waterdichting door middel van injectieharsen in man-toegankelijke riolen',
                                                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/waterdichting-door-middel-van-injectieharsen-in-man-toegankelijke-riolen'),
        'waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-manchette': KeuzelijstWaarde(invulwaarde='waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-manchette',
                                                                                                       label='waterdichting van lekkende voegverbindingen van ronde buizen dmv manchette',
                                                                                                       status='ingebruik',
                                                                                                       definitie='Waterdichting van lekkende voegverbindingen van ronde buizen dmv manchette',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-manchette'),
        'waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-uitwendige-krimpmof': KeuzelijstWaarde(invulwaarde='waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-uitwendige-krimpmof',
                                                                                                                 label='waterdichting van lekkende voegverbindingen van ronde buizen dmv uitwendige krimpmof',
                                                                                                                 status='ingebruik',
                                                                                                                 definitie='Waterdichting van lekkende voegverbindingen van ronde buizen dmv uitwendige krimpmof',
                                                                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-uitwendige-krimpmof')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

