# coding=utf-8
from otlmow_model.Classes.Onderdeel.BloemrijkGraslandGraslandfase4 import BloemrijkGraslandGraslandfase4


# Generated with OTLClassCreator. To modify: extend, do not edit
class BloemrijkVochtigTotNatGrasland(BloemrijkGraslandGraslandfase4):
    """G4e - echte koekoeksbloem, grote ratelaar, kruipend zenegroen, moeras/zompvergeet-me-nietje, dotterbloem, kale jonker, lidrus, moerasrolklaver, moeraswalstro, egelboterbloem, pinksterbloem, slanke sleutelbloem, tweerijige zegge, gewone waterbies, heelblaadjes, penningkruid, pijptorkruid, zomprus."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BloemrijkVochtigTotNatGrasland'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
