# coding=utf-8
from otlmow_model.Classes.Onderdeel.Struweel import Struweel


# Generated with OTLClassCreator. To modify: extend, do not edit
class DwergstruikvegetatieHeidesoorten(Struweel):
    """S1 - struikheide, dopheide, blauwe bosbes,stekelbrem, kruipbrem."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DwergstruikvegetatieHeidesoorten'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
