# coding=utf-8
from otlmow_model.Classes.Onderdeel.Struweel import Struweel


# Generated with OTLClassCreator. To modify: extend, do not edit
class Vlierstruweel(Struweel):
    """S5 - gewone vlier (dominant)."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Vlierstruweel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
