# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSignaalkabelAdersEnSectie(KeuzelijstField):
    """Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een signalisatiekabel volgens het aantal aders en hun sectie in vierkante millimeter."""
    naam = 'KlSignaalkabelAdersEnSectie'
    label = 'Voedingskabel aders specificaties'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSignaalkabelAdersEnSectie'
    definition = 'Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een signalisatiekabel volgens het aantal aders en hun sectie in vierkante millimeter.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSignaalkabelAdersEnSectie'
    options = {
        '1.5': KeuzelijstWaarde(invulwaarde='1.5',
                                label='1.5',
                                status='ingebruik',
                                definitie='1.5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/1.5'),
        '10-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='10-x-1.5-mm2',
                                         label='10 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10-x-1.5-mm2'),
        '10-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='10-x-2.5-mm2',
                                         label='10 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10-x-2.5-mm2'),
        '10x1.5': KeuzelijstWaarde(invulwaarde='10x1.5',
                                   label='10x1.5',
                                   status='ingebruik',
                                   definitie='10x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10x1.5'),
        '10x2x0.2': KeuzelijstWaarde(invulwaarde='10x2x0.2',
                                     label='10x2x0.2',
                                     status='ingebruik',
                                     definitie='10x2x0.2',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10x2x0.2'),
        '10x2x0.5': KeuzelijstWaarde(invulwaarde='10x2x0.5',
                                     label='10x2x0.5',
                                     status='ingebruik',
                                     definitie='10x2x0.5',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10x2x0.5'),
        '10x2x0.8': KeuzelijstWaarde(invulwaarde='10x2x0.8',
                                     label='10x2x0.8',
                                     status='ingebruik',
                                     definitie='10x2x0.8',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/10x2x0.8'),
        '12-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='12-x-1.5-mm2',
                                         label='12 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12-x-1.5-mm2'),
        '12x0.75': KeuzelijstWaarde(invulwaarde='12x0.75',
                                    label='12x0.75',
                                    status='ingebruik',
                                    definitie='12x0.75',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x0.75'),
        '12x1.5': KeuzelijstWaarde(invulwaarde='12x1.5',
                                   label='12x1.5',
                                   status='ingebruik',
                                   definitie='12x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x1.5'),
        '12x2.5': KeuzelijstWaarde(invulwaarde='12x2.5',
                                   label='12x2.5',
                                   status='ingebruik',
                                   definitie='12x2.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x2.5'),
        '12x2x0.8': KeuzelijstWaarde(invulwaarde='12x2x0.8',
                                     label='12x2x0.8',
                                     status='ingebruik',
                                     definitie='12x2x0.8',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x2x0.8'),
        '12x3.5': KeuzelijstWaarde(invulwaarde='12x3.5',
                                   label='12x3.5',
                                   status='ingebruik',
                                   definitie='12x3.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/12x3.5'),
        '14-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='14-x-1.5-mm2',
                                         label='14 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/14-x-1.5-mm2'),
        '14-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='14-x-2.5-mm2',
                                         label='14 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/14-x-2.5-mm2'),
        '14x1.5': KeuzelijstWaarde(invulwaarde='14x1.5',
                                   label='14x1.5',
                                   status='ingebruik',
                                   definitie='14x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/14x1.5'),
        '16-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='16-x-1.5-mm2',
                                         label='16 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/16-x-1.5-mm2'),
        '16-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='16-x-2.5-mm2',
                                         label='16 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/16-x-2.5-mm2'),
        '18x1.5': KeuzelijstWaarde(invulwaarde='18x1.5',
                                   label='18x1.5',
                                   status='ingebruik',
                                   definitie='18x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/18x1.5'),
        '19-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='19-x-1.5-mm2',
                                         label='19 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/19-x-1.5-mm2'),
        '19-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='19-x-2.5-mm2',
                                         label='19 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/19-x-2.5-mm2'),
        '19x1.5': KeuzelijstWaarde(invulwaarde='19x1.5',
                                   label='19x1.5',
                                   status='ingebruik',
                                   definitie='19x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/19x1.5'),
        '1x1.5': KeuzelijstWaarde(invulwaarde='1x1.5',
                                  label='1x1.5',
                                  status='ingebruik',
                                  definitie='1x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/1x1.5'),
        '1x2x0.8': KeuzelijstWaarde(invulwaarde='1x2x0.8',
                                    label='1x2x0.8',
                                    status='ingebruik',
                                    definitie='1x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/1x2x0.8'),
        '20x1.5': KeuzelijstWaarde(invulwaarde='20x1.5',
                                   label='20x1.5',
                                   status='ingebruik',
                                   definitie='20x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/20x1.5'),
        '21-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='21-x-1.5-mm2',
                                         label='21 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/21-x-1.5-mm2'),
        '21-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='21-x-2.5-mm2',
                                         label='21 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/21-x-2.5-mm2'),
        '21x2x0.8': KeuzelijstWaarde(invulwaarde='21x2x0.8',
                                     label='21x2x0.8',
                                     status='ingebruik',
                                     definitie='21x2x0.8',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/21x2x0.8'),
        '24-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='24-x-1.5-mm2',
                                         label='24 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/24-x-1.5-mm2'),
        '24-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='24-x-2.5-mm2',
                                         label='24 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/24-x-2.5-mm2'),
        '25x0.75': KeuzelijstWaarde(invulwaarde='25x0.75',
                                    label='25x0.75',
                                    status='ingebruik',
                                    definitie='25x0.75',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/25x0.75'),
        '25x1.5': KeuzelijstWaarde(invulwaarde='25x1.5',
                                   label='25x1.5',
                                   status='ingebruik',
                                   definitie='25x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/25x1.5'),
        '27-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='27-x-1.5-mm2',
                                         label='27 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/27-x-1.5-mm2'),
        '27-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='27-x-2.5-mm2',
                                         label='27 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/27-x-2.5-mm2'),
        '27x1.5': KeuzelijstWaarde(invulwaarde='27x1.5',
                                   label='27x1.5',
                                   status='ingebruik',
                                   definitie='27x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/27x1.5'),
        '2x0.75': KeuzelijstWaarde(invulwaarde='2x0.75',
                                   label='2x0.75',
                                   status='ingebruik',
                                   definitie='2x0.75',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x0.75'),
        '2x1.5': KeuzelijstWaarde(invulwaarde='2x1.5',
                                  label='2x1.5',
                                  status='ingebruik',
                                  definitie='2x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x1.5'),
        '2x2.5': KeuzelijstWaarde(invulwaarde='2x2.5',
                                  label='2x2.5',
                                  status='ingebruik',
                                  definitie='2x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2.5'),
        '2x2x0.5': KeuzelijstWaarde(invulwaarde='2x2x0.5',
                                    label='2x2x0.5',
                                    status='ingebruik',
                                    definitie='2x2x0.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2x0.5'),
        '2x2x0.75': KeuzelijstWaarde(invulwaarde='2x2x0.75',
                                     label='2x2x0.75',
                                     status='ingebruik',
                                     definitie='2x2x0.75',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2x0.75'),
        '2x2x0.8': KeuzelijstWaarde(invulwaarde='2x2x0.8',
                                    label='2x2x0.8',
                                    status='ingebruik',
                                    definitie='2x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2x0.8'),
        '2x2x2.5': KeuzelijstWaarde(invulwaarde='2x2x2.5',
                                    label='2x2x2.5',
                                    status='ingebruik',
                                    definitie='2x2x2.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x2x2.5'),
        '2x4': KeuzelijstWaarde(invulwaarde='2x4',
                                label='2x4',
                                status='ingebruik',
                                definitie='2x4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/2x4'),
        '30-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='30-x-1.5-mm2',
                                         label='30 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/30-x-1.5-mm2'),
        '30-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='30-x-2.5-mm2',
                                         label='30 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/30-x-2.5-mm2'),
        '30x1.5': KeuzelijstWaarde(invulwaarde='30x1.5',
                                   label='30x1.5',
                                   status='ingebruik',
                                   definitie='30x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/30x1.5'),
        '30x2.5': KeuzelijstWaarde(invulwaarde='30x2.5',
                                   label='30x2.5',
                                   status='ingebruik',
                                   definitie='30x2.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/30x2.5'),
        '33-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='33-x-1.5-mm2',
                                         label='33 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/33-x-1.5-mm2'),
        '33-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='33-x-2.5-mm2',
                                         label='33 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/33-x-2.5-mm2'),
        '37-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='37-x-1.5-mm2',
                                         label='37 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/37-x-1.5-mm2'),
        '37-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='37-x-2.5-mm2',
                                         label='37 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/37-x-2.5-mm2'),
        '37x1.5': KeuzelijstWaarde(invulwaarde='37x1.5',
                                   label='37x1.5',
                                   status='ingebruik',
                                   definitie='37x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/37x1.5'),
        '3x0.75': KeuzelijstWaarde(invulwaarde='3x0.75',
                                   label='3x0.75',
                                   status='ingebruik',
                                   definitie='3x0.75',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/3x0.75'),
        '3x1.5': KeuzelijstWaarde(invulwaarde='3x1.5',
                                  label='3x1.5',
                                  status='ingebruik',
                                  definitie='3x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/3x1.5'),
        '40-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='40-x-1.5-mm2',
                                         label='40 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/40-x-1.5-mm2'),
        '40-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='40-x-2.5-mm2',
                                         label='40 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/40-x-2.5-mm2'),
        '44-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='44-x-1.5-mm2',
                                         label='44 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/44-x-1.5-mm2'),
        '44-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='44-x-2.5-mm2',
                                         label='44 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/44-x-2.5-mm2'),
        '48-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='48-x-1.5-mm2',
                                         label='48 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/48-x-1.5-mm2'),
        '48-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='48-x-2.5-mm2',
                                         label='48 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/48-x-2.5-mm2'),
        '48x0.8': KeuzelijstWaarde(invulwaarde='48x0.8',
                                   label='48x0.8',
                                   status='ingebruik',
                                   definitie='48x0.8',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/48x0.8'),
        '48x1.5': KeuzelijstWaarde(invulwaarde='48x1.5',
                                   label='48x1.5',
                                   status='ingebruik',
                                   definitie='48x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/48x1.5'),
        '4x0.8': KeuzelijstWaarde(invulwaarde='4x0.8',
                                  label='4x0.8',
                                  status='ingebruik',
                                  definitie='4x0.8',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x0.8'),
        '4x1.5': KeuzelijstWaarde(invulwaarde='4x1.5',
                                  label='4x1.5',
                                  status='ingebruik',
                                  definitie='4x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x1.5'),
        '4x2.5': KeuzelijstWaarde(invulwaarde='4x2.5',
                                  label='4x2.5',
                                  status='ingebruik',
                                  definitie='4x2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x2.5'),
        '4x25': KeuzelijstWaarde(invulwaarde='4x25',
                                 label='4x25',
                                 status='ingebruik',
                                 definitie='4x25',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x25'),
        '4x25-16': KeuzelijstWaarde(invulwaarde='4x25-16',
                                    label='4x25+16',
                                    status='ingebruik',
                                    definitie='4x25+16',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x25-16'),
        '4x2x0.5': KeuzelijstWaarde(invulwaarde='4x2x0.5',
                                    label='4x2x0.5',
                                    status='ingebruik',
                                    definitie='4x2x0.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x2x0.5'),
        '4x2x0.8': KeuzelijstWaarde(invulwaarde='4x2x0.8',
                                    label='4x2x0.8',
                                    status='ingebruik',
                                    definitie='4x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/4x2x0.8'),
        '5-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='5-x-1.5-mm2',
                                        label='5 x 1.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/5-x-1.5-mm2'),
        '5-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='5-x-2.5-mm2',
                                        label='5 x 2.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/5-x-2.5-mm2'),
        '5x0.75': KeuzelijstWaarde(invulwaarde='5x0.75',
                                   label='5x0.75',
                                   status='ingebruik',
                                   definitie='5x0.75',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/5x0.75'),
        '5x2x0.8': KeuzelijstWaarde(invulwaarde='5x2x0.8',
                                    label='5x2x0.8',
                                    status='ingebruik',
                                    definitie='5x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/5x2x0.8'),
        '60x1.5': KeuzelijstWaarde(invulwaarde='60x1.5',
                                   label='60x1.5',
                                   status='ingebruik',
                                   definitie='60x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/60x1.5'),
        '61-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='61-x-1.5-mm2',
                                         label='61 x 1.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/61-x-1.5-mm2'),
        '61-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='61-x-2.5-mm2',
                                         label='61 x 2.5 mm²',
                                         status='ingebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/61-x-2.5-mm2'),
        '61x1.5': KeuzelijstWaarde(invulwaarde='61x1.5',
                                   label='61x1.5',
                                   status='ingebruik',
                                   definitie='61x1.5',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/61x1.5'),
        '7-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='7-x-1.5-mm2',
                                        label='7 x 1.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7-x-1.5-mm2'),
        '7-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='7-x-2.5-mm2',
                                        label='7 x 2.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7-x-2.5-mm2'),
        '7x0.75': KeuzelijstWaarde(invulwaarde='7x0.75',
                                   label='7x0.75',
                                   status='ingebruik',
                                   definitie='7x0.75',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7x0.75'),
        '7x1.5': KeuzelijstWaarde(invulwaarde='7x1.5',
                                  label='7x1.5',
                                  status='ingebruik',
                                  definitie='7x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7x1.5'),
        '7x2x0.8': KeuzelijstWaarde(invulwaarde='7x2x0.8',
                                    label='7x2x0.8',
                                    status='ingebruik',
                                    definitie='7x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/7x2x0.8'),
        '8-x-1.5-mm2': KeuzelijstWaarde(invulwaarde='8-x-1.5-mm2',
                                        label='8 x 1.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8-x-1.5-mm2'),
        '8-x-2.5-mm2': KeuzelijstWaarde(invulwaarde='8-x-2.5-mm2',
                                        label='8 x 2.5 mm²',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8-x-2.5-mm2'),
        '8x1.5': KeuzelijstWaarde(invulwaarde='8x1.5',
                                  label='8x1.5',
                                  status='ingebruik',
                                  definitie='8x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8x1.5'),
        '8x2x0.5': KeuzelijstWaarde(invulwaarde='8x2x0.5',
                                    label='8x2x0.5',
                                    status='ingebruik',
                                    definitie='8x2x0.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8x2x0.5'),
        '8x2x0.8': KeuzelijstWaarde(invulwaarde='8x2x0.8',
                                    label='8x2x0.8',
                                    status='ingebruik',
                                    definitie='8x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/8x2x0.8'),
        'zonder-bijkomende-specificatie': KeuzelijstWaarde(invulwaarde='zonder-bijkomende-specificatie',
                                                           label='zonder bijkomende specificatie',
                                                           status='ingebruik',
                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignaalkabelAdersEnSectie/zonder-bijkomende-specificatie')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

