# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlRadiolistenerModelnaam(KeuzelijstField):
    """Modelnaam van de radiolistener module."""
    naam = 'KlRadiolistenerModelnaam'
    label = 'Radiolistener modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlRadiolistenerModelnaam'
    definition = 'Modelnaam van de radiolistener module.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlRadiolistenerModelnaam'
    options = {
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

