# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTelecomkabelAdersEnSectie(KeuzelijstField):
    """Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een telecomkabel volgens het aantal aders en hun dikte in vierkante millimeter."""
    naam = 'KlTelecomkabelAdersEnSectie'
    label = 'Telecomkabel aders en sectie'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlTelecomkabelAdersEnSectie'
    definition = 'Lijst van mogelijke waarden volgens de catalogusposten van het standaardbestek voor de samenstelling van een telecomkabel volgens het aantal aders en hun dikte in vierkante millimeter.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTelecomkabelAdersEnSectie'
    options = {
        '100-x-2-x-1-mm2': KeuzelijstWaarde(invulwaarde='100-x-2-x-1-mm2',
                                            label='100 x 2 X 1 mm²',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/100-x-2-x-1-mm2'),
        '10x4x1': KeuzelijstWaarde(invulwaarde='10x4x1',
                                   label='10x4x1',
                                   status='ingebruik',
                                   definitie='10x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/10x4x1'),
        '12': KeuzelijstWaarde(invulwaarde='12',
                               label='12',
                               status='ingebruik',
                               definitie='12',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/12'),
        '20-x-2-x-1-mm2': KeuzelijstWaarde(invulwaarde='20-x-2-x-1-mm2',
                                           label='20 x 2 X 1 mm²',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/20-x-2-x-1-mm2'),
        '20x4x1': KeuzelijstWaarde(invulwaarde='20x4x1',
                                   label='20x4x1',
                                   status='ingebruik',
                                   definitie='20x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/20x4x1'),
        '21-x-2-x-1-mm2': KeuzelijstWaarde(invulwaarde='21-x-2-x-1-mm2',
                                           label='21 x 2 X 1 mm²',
                                           status='ingebruik',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/21-x-2-x-1-mm2'),
        '24': KeuzelijstWaarde(invulwaarde='24',
                               label='24',
                               status='ingebruik',
                               definitie='24',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/24'),
        '25x4x1': KeuzelijstWaarde(invulwaarde='25x4x1',
                                   label='25x4x1',
                                   status='ingebruik',
                                   definitie='25x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/25x4x1'),
        '30x4x1': KeuzelijstWaarde(invulwaarde='30x4x1',
                                   label='30x4x1',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/30x4x1'),
        '32x4x1': KeuzelijstWaarde(invulwaarde='32x4x1',
                                   label='32x4x1',
                                   status='ingebruik',
                                   definitie='32x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/32x4x1'),
        '34x4x1': KeuzelijstWaarde(invulwaarde='34x4x1',
                                   label='34x4x1',
                                   status='ingebruik',
                                   definitie='34x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/34x4x1'),
        '4': KeuzelijstWaarde(invulwaarde='4',
                              label='4',
                              status='ingebruik',
                              definitie='4',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/4'),
        '40x4x1': KeuzelijstWaarde(invulwaarde='40x4x1',
                                   label='40x4x1',
                                   status='ingebruik',
                                   definitie='40x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/40x4x1'),
        '48': KeuzelijstWaarde(invulwaarde='48',
                               label='48',
                               status='ingebruik',
                               definitie='48',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/48'),
        '48-vezels': KeuzelijstWaarde(invulwaarde='48-vezels',
                                      label='48 vezels',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/48-vezels'),
        '50x4x1': KeuzelijstWaarde(invulwaarde='50x4x1',
                                   label='50x4x1',
                                   status='ingebruik',
                                   definitie='50x4x1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/50x4x1'),
        '5x4x1': KeuzelijstWaarde(invulwaarde='5x4x1',
                                  label='5x4x1',
                                  status='ingebruik',
                                  definitie='5x4x1',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/5x4x1'),
        '7x1.5': KeuzelijstWaarde(invulwaarde='7x1.5',
                                  label='7x1.5',
                                  status='ingebruik',
                                  definitie='7x1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/7x1.5'),
        '7x2x0.8': KeuzelijstWaarde(invulwaarde='7x2x0.8',
                                    label='7x2x0.8',
                                    status='ingebruik',
                                    definitie='7x2x0.8',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/7x2x0.8'),
        '8': KeuzelijstWaarde(invulwaarde='8',
                              label='8',
                              status='ingebruik',
                              definitie='8',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/8'),
        '96-vezels': KeuzelijstWaarde(invulwaarde='96-vezels',
                                      label='96 vezels',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/96-vezels'),
        'onbekend': KeuzelijstWaarde(invulwaarde='onbekend',
                                     label='onbekend',
                                     status='ingebruik',
                                     definitie='onbekend',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/onbekend'),
        'zonder-verdere-specificatie': KeuzelijstWaarde(invulwaarde='zonder-verdere-specificatie',
                                                        label='zonder verdere specificatie',
                                                        status='ingebruik',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTelecomkabelAdersEnSectie/zonder-verdere-specificatie')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

